require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_dhcpserveroptionvalue',
  dscmeta_resource_friendly_name: 'DhcpServerOptionValue',
  dscmeta_resource_name: 'MSFT_DhcpServerOptionValue',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDhcpServer',
  dscmeta_module_version: '3.0.0',
  docs: 'The DSC DhcpServerOptionValue resource type.
         Automatically generated from version 3.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_addressfamily: {
      type: "Enum['IPv4']",
      desc: 'Address family. Currently needs to be IPv4.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Whether the DHCP option should exist.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_vendorclass: {
      type: 'String',
      desc: 'Vendor class. Use an empty string for default vendor class.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_userclass: {
      type: 'String',
      desc: 'User class. Use an empty string for default user class.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_value: {
      type: 'Optional[Array[String]]',
      desc: 'Option data value. Could be an array of string for a multivalued option.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_optionid: {
      type: 'Integer[0, 4294967295]',
      desc: 'Option ID, specify an integer between 1 and 255.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
