require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xdhcpserverscope',
  dscmeta_resource_friendly_name: 'xDhcpServerScope',
  dscmeta_resource_name: 'MSFT_xDhcpServerScope',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xDhcpServer',
  dscmeta_module_version: '3.0.0',
  docs: 'The DSC xDhcpServerScope resource type.
         Automatically generated from version 3.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_leaseduration: {
      type: 'Optional[String]',
      desc: 'Time interval for which an IP address should be leased',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ipendrange: {
      type: 'String',
      desc: 'Ending address to set for this scope',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_addressfamily: {
      type: "Optional[Enum['IPv4']]",
      desc: 'Address family type',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Whether scope should be set or removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of DHCP Scope',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_subnetmask: {
      type: 'String',
      desc: 'Subnet mask for the scope specified in IP address format',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['Active', 'Inactive']]",
      desc: 'Whether scope should be active or inactive',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of DHCP Scope',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ipstartrange: {
      type: 'String',
      desc: 'Starting address to set for this scope',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_scopeid: {
      type: 'String',
      desc: 'ScopeId for the given scope',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
